==> fet_5.38.1.orig.tar.bz2: fet-5.38.1/src/interface/addconstraintteachersmaxspanperdayform.cpp <==
/***************************************************************************
                          addconstraintteachersmaxspanperdayform.cpp  -  description
                             -------------------
    begin                : 2017
    copyright            : (C) 2017 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include <QMessageBox>

#include "longtextmessagebox.h"

#include "addconstraintteachersmaxspanperdayform.h"
#include "timeconstraint.h"

AddConstraintTeachersMaxSpanPerDayForm::AddConstraintTeachersMaxSpanPerDayForm(QWidget* parent): QDialog(parent)
{
	setupUi(this);

	addConstraintPushButton->setDefault(true);

	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));

	centerWidgetOnScreen(this);
	restoreFETDialogGeometry(this);
		
	maxSpanSpinBox->setMinimum(1);
	maxSpanSpinBox->setMaximum(gt.rules.nHoursPerDay);
	maxSpanSpinBox->setValue(gt.rules.nHoursPerDay);
	
	constraintChanged();
}

AddConstraintTeachersMaxSpanPerDayForm::~AddConstraintTeachersMaxSpanPerDayForm()
{
	saveFETDialogGeometry(this);
}

void AddConstraintTeachersMaxSpanPerDayForm::constraintChanged()
{
}

void AddConstraintTeachersMaxSpanPerDayForm::addCurrentConstraint()
{
	TimeConstraint *ctr=NULL;

	double weight;
	QString tmp=weightLineEdit->text();
	weight_sscanf(tmp, "%lf", &weight);
	if(weight<0.0 || weight>100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage)"));
		return;
	}
	if(weight!=100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage) - it must be 100%"));
		return;
	}

	ctr=new ConstraintTeachersMaxSpanPerDay(weight, maxSpanSpinBox->value());

	bool tmp2=gt.rules.addTimeConstraint(ctr);
	if(tmp2)
		LongTextMessageBox::information(this, tr("FET information"),
			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
	else{
		QMessageBox::warning(this, tr("FET information"),
			tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}

==> fet_5.41.0.orig.tar.bz2: fet-5.41.0/src/interface/addconstraintteachersmaxspanperdayform.cpp <==
/***************************************************************************
                          addconstraintteachersmaxspanperdayform.cpp  -  description
                             -------------------
    begin                : 2017
    copyright            : (C) 2017 by Lalescu Liviu
    email                : Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software: you can redistribute it and/or modify  *
 *   it under the terms of the GNU Affero General Public License as        *
 *   published by the Free Software Foundation, either version 3 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 ***************************************************************************/

#include <QMessageBox>

#include "longtextmessagebox.h"

#include "addconstraintteachersmaxspanperdayform.h"
#include "timeconstraint.h"

AddConstraintTeachersMaxSpanPerDayForm::AddConstraintTeachersMaxSpanPerDayForm(QWidget* parent): QDialog(parent)
{
	setupUi(this);

	addConstraintPushButton->setDefault(true);

	connect(addConstraintPushButton, SIGNAL(clicked()), this, SLOT(addCurrentConstraint()));
	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));

	centerWidgetOnScreen(this);
	restoreFETDialogGeometry(this);
		
	maxSpanSpinBox->setMinimum(1);
	maxSpanSpinBox->setMaximum(gt.rules.nHoursPerDay);
	maxSpanSpinBox->setValue(gt.rules.nHoursPerDay);

	exceptionCheckBox->setChecked(false);
	
	constraintChanged();
}

AddConstraintTeachersMaxSpanPerDayForm::~AddConstraintTeachersMaxSpanPerDayForm()
{
	saveFETDialogGeometry(this);
}

void AddConstraintTeachersMaxSpanPerDayForm::constraintChanged()
{
}

void AddConstraintTeachersMaxSpanPerDayForm::addCurrentConstraint()
{
	TimeConstraint *ctr=NULL;

	double weight;
	QString tmp=weightLineEdit->text();
	weight_sscanf(tmp, "%lf", &weight);
	if(weight<0.0 || weight>100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage)"));
		return;
	}
	if(weight!=100.0){
		QMessageBox::warning(this, tr("FET information"),
			tr("Invalid weight (percentage) - it must be 100%"));
		return;
	}

	ctr=new ConstraintTeachersMaxSpanPerDay(weight, maxSpanSpinBox->value(), exceptionCheckBox->isChecked());

	bool tmp2=gt.rules.addTimeConstraint(ctr);
	if(tmp2)
		LongTextMessageBox::information(this, tr("FET information"),
			tr("Constraint added:")+"\n\n"+ctr->getDetailedDescription(gt.rules));
	else{
		QMessageBox::warning(this, tr("FET information"),
			tr("Constraint NOT added - please report error"));
		delete ctr;
	}
}
